@@ -32,7 +32,7 @@ for key in ('depends', 'extras_depend', 'xml'):
         info[key] = info[key].strip().splitlines()
 major_version, minor_version = 3, 2
 
-requires = []
+requires = ['qrcode']
 
 for dep in info.get('depends', []):
     if dep.startswith('health'):
